#container {
  position: absolute;
  height: 100%;
  width: 100%;
}
#accordion {
  position: fixed;
  float: left;
  height: 100%;
  width: 20%;
}
#tabs {
  position: relative;
  float: right;
  height: 100%;
  width: 80%;
}
#node-selector-container {
  border: 1px solid black;
  position: absolute;
}
#scenario-tab {
  height: 100%;
  width: 100%;
}
#scenario-container {
  position: relative;
  height: 100%;
  width: 100%;
}
